#!/bin/bash
#
# USAGE: Usage: launch.sh {start|stop}
#
# TODO: use start-stop-daemon instead of _start?
#
# BUGS:
#	* script does not intercept return code of _start function
#	execution of "python ${DAEMON}…" may fails without warning


DIR=$(dirname $0)
NAME=mpd_sima
DAEMON=${DIR}/src/mpd_sima.py

## Set these var to fit your preferences
PIDFILE="${DIR}/${NAME}.pid"
LOG_DIR="${DIR}/"
##

##Compatibility with previous launc.sh
if [ -z "$1" ]
then
        [[ -e "$PIDFILE" ]] && \
        { echo "$DAEMON already running? check and remove $PIDFILE please"; exit 1; }
        echo "Usage: $0 {start|stop}" >&1
        python ${DAEMON}
fi

function _start() {
python "${DAEMON}" --pid="${PIDFILE}" 2>&1 >> "${LOG_DIR}/$NAME.log" &
}

[ -e $PIDFILE ] && PID=$(cat "$PIDFILE")

case "$1" in
  start)
	echo -n "Starting ${NAME}: "
	if ( [[ -w $PIDFILE ]] && ps -p $PID 1> /dev/null )
	then
		echo "ERROR: ${NAME} already started ($NAME found running PID's $PID)"
		exit 1
	elif ( [[ -w $PIDFILE ]] )
	then
		echo "ERROR: PID file found while ${NAME} is not running (removing PID file)."
		echo "Starting again."
		rm $PIDFILE
		_start
		exit 0
	fi
	_start
	echo "done"
	exit 0
    ;;
  stop)
	echo -n "Stopping ${NAME}: "
	if !([[ -w $PIDFILE ]])
	then 
		echo "ERROR: Is ${NAME} running? PID file not found."
		exit 1
	fi
	kill -15 $PID
	rm $PIDFILE
	echo "done"
	exit 0
    ;;
  *)
    echo "Usage: $0 {start|stop}" >&2
    exit 1
    ;;
esac

exit 0

# vim: nolist
