# -*- coding: utf-8 -*-

#    Copyright (c) 2009 Efrim <efrim@azylum.org> {{{
#    Copyright (C) 2008 Grégoire Menuel <xmpp:omega@im.apinc.org>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, version 3 of the License only.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#    }}}

import sys
import time
from socket import error as socketerror

try:
    import mpd
    from mpd import MPDError as MPDPasswordError
except ImportError, err:
    print 'ERROR: "%s"\n\nPlease install python-mpd module.\n' % err
    sys.exit(1)


WAIT_RECONNECT=30


class MpdConnector:
    """MPD connection and info Class"""

    def __init__(self, host='localhost', port='6600', password=None):
        self.mpd_cli =  mpd.MPDClient()
        self.lastchange=0
        self.host = host
        self.port = int(port)
        self.password = password

    def connect(self):
        try:
            self.mpd_cli.connect(self.host, self.port)
        except socketerror:
            return False
        return True

    def auth(self):
        try:
            self.mpd_cli.password(self.password)
        except mpd.CommandError, err:
            raise MPDPasswordError(err)
        return True

    def disconnect(self):
        try:
            self.mpd_cli.disconnect()
        except mpd.ConnectionError, errdisco:
            print errdisco
        return True

    def is_connected(self):
        try:
            self.mpd_cli.ping()
        except (socketerror):
            return False
        except (mpd.ConnectionError):
            return False
        return True

    def is_playing(self):
        play = self.mpd_cli.status()["state"]
        if (play == 'play'):
            return True
        else:
            return False

    def status(self):
        return self.mpd_cli.status()

    def currentsong(self):
        return self.mpd_cli.currentsong()

    def playlistinfo(self):
        return self.mpd_cli.playlistinfo()

    def search(self, type, query):
        return self.mpd_cli.search(type, query)

    def find(self, type, query):
        return self.mpd_cli.find(type, query)

    def add(self, file):
        self.mpd_cli.add(file)

    def cmd(self):
        return self.mpd_cli.commands()


if __name__ == "__main__":#{{{

    mpd_con = MpdConnector(host='libertalia', password="my_password")

    if not mpd_con.connect():
        print "Unable to connect to MPD, exiting"
        sys.exit(2)

    try:
        #mpd_con.auth()
        print "auth pass"
    except MPDPasswordError, err:
        print "auth failed"
        sys.exit(1)

    print mpd_con.currentsong()['file'].strip()
    print type(mpd_con.currentsong()['file'])
    print mpd_con.search('artist',"JMPZ")
    #print mpd_con.mpd_cli.playlistinfo(mpd_con.status()['song'])
    #print mpd_con.status()['song']
    cursonpos = int(mpd_con.currentsong()['pos'])
    #playlist_dict = mpd_con.playlistinfo()
    #print playlist_dict
    #print mpd_con.mpd_cli.playlistinfo()
    #for song in [ track['file'] for track in playlist_dict[cursonpos:] ]:
    #    print song
    sys.exit(0)

# VIM MODLINE
# vim: ai ts=4 sw=4 sts=4 expandtab
