# -*- coding: utf-8 -*-

#    Copyright (c) 2009 Efrim <efrim@azylum.org> {{{
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, version 3 of the License only.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
#  }}}
"""
Logging facility for MPD_sima.
"""

import logging
import sys

#CONSTANT{{{

LEVELS = {'debug': logging.DEBUG,
        'info': logging.INFO,
        'warning': logging.WARNING,
        'error': logging.ERROR,
        'critical': logging.CRITICAL}

LOG_FORMAT = '%(asctime)s - %(levelname)-9s %(message)s'
#LOG_FORMAT = '%(lineno)d:%(funcName)s - %(levelname)-9s %(message)s'
#LOG_FORMAT = '%(asctime)s : %(lineno)d - %(levelname)-9s %(message)s'

LOG_FORMATS = {'debug': '%(asctime)s : %(levelname)-9s %(message)s',
        'info': '%(levelname)-9s: %(message)s'}
DATE_FMT = "%Y-%m-%d %H:%M:%S"

#}}}


class LevelFilter(logging.Filter):# Logging facility {{{
    """
    Enable logging between two log level by filtering everything < level.
    """

    def __init__(self, filt_level):
        logging.Filter.__init__(self)
        self.level = filt_level

    def filter(self, record):
        """Defines loglevel"""
        return record.levelno <= self.level
    #}}}


def sima_logger(log_level='info', log_file=None):#{{{
    """
    TODO: Add diferent logger format for info / debug
    """

    user_log_level = LEVELS.get(log_level, logging.INFO)
    logger = logging.getLogger("simaLoggerOut")
    formatter = logging.Formatter(LOG_FORMAT, DATE_FMT)
    logger.setLevel(user_log_level)
    if log_file:
        # create file handler which logs even debug messages
        fileh = logging.FileHandler("spam.log")
        #fileh.setLevel(user_log_level)
        fileh.setFormatter(formatter)
        logger.addHandler(fileh)
    else:
        # create console handler with a specified log level (STDOUT)
        couth = logging.StreamHandler(sys.stdout)
        #couth.setLevel(user_log_level)
        couth.addFilter(LevelFilter(logging.WARNING))

        # create console handler with warning log level (STDERR)
        cerrh = logging.StreamHandler(sys.stderr)
        #cerrh.setLevel(logging.WARNING)
        cerrh.setLevel(logging.ERROR)

        # add formatter to the handlers
        cerrh.setFormatter(formatter)
        couth.setFormatter(formatter)

        # add the handlers to SIMA_LOGGER
        logger.addHandler(couth)
        logger.addHandler(cerrh)

    return logger

#}}}

# VIM MODLINE
# vim: ai ts=4 sw=4 sts=4 expandtab


