# -*- coding: utf-8 -*-

#
# Copyright (c) 2009 Efrim <efrim@azylum.org> {{{
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation; either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful, but
#  WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#  Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public
#  License along with this program.
#  If not, see <http://www.gnu.org/licenses/>.
#
#  }}}
"""
Command line invocation management.
DOC: http://docs.python.org/library/getopt.html
"""

import getopt

from os import getpid, environ
from os.path import join, isfile, expanduser
from sys import argv, exit

USAGE = u'USAGE:\n\t%s [--pid=/path/to/pid_file.pid] [--version|-v] [--help|-h]\n' % argv[0]
CONFIGURATION = u'Configuration file is located in $XDG_CONFIG_HOME (usually $HOME/.config/)'

class StartOpt():
    """
    """

    def __init__(self, logging_object, script_info):
        self.logger = logging_object
        self.sima_info = script_info
        self.options_list = ['pid=', 'version', 'help']
        self.cmd_line_opt()

    def usage(self):#{{{
        usage_msg = """
        """
        self.logger.info(USAGE)#}}}

    def help(self):#{{{
        """Help message"""
        print USAGE
        print CONFIGURATION#}}}

    def opt_pid(self, pid_file):#{{{
        """PID file option"""
        self.logger.debug(u'Writing pid file to "%s"' %
                          unicode(pid_file,'utf-8'))
        try:
            fd_p = open(pid_file, 'w')
            fd_p.write(str(getpid()))
            fd_p.close()
        except IOError, getopt_err:
            self.logger.error(u'Error trying to write pid file to %s: %s' %
                (unicode(pid_file,'utf-8'), getopt_err))
            return False
        return True#}}}

    def opt_version(self):#{{{
        print (u'This is MPD_sima version %s (revision %i - %s)' %
                   (self.sima_info[0], int(self.sima_info[1]), self.sima_info[2]))
        #}}}

    def opt_purge_hist(self):#{{{
        """Purge history."""

        homedir = expanduser('~')

        if environ.get('XDG_DATA_HOME'):
            data_dir = join(environ.get('XDG_DATA_HOME'), 'mpd_sima')
        else:
            data_dir = join(homedir, '.local', 'share', 'mpd_sima')

        if isfile(join(data_dir, "history.pkl")):
            self.logger('Delete history.')#}}}

    def e_options(self):#{{{
        """
        Script options management.
        Return False if something went wrong.
        """
        try:
            optlist, args = getopt.getopt(argv[1:], 'vh', self.options_list)
        except getopt.GetoptError, getopt_err:
            print(u'Error calling mpd_sima.py: %s' % getopt_err)
            return False

        for opt_tuple in optlist:
            if opt_tuple[0] == '--pid':
                if not self.opt_pid(opt_tuple[1]):
                    self.usage()
                    exit(1)
            elif opt_tuple[0] in ('--help', '-h'):
                self.help()
                exit(0)
            elif opt_tuple[0] in ('--version', '-v'):
                self.opt_version()
                exit(0)
            return True#}}}

    def cmd_line_opt(self):#{{{
        if argv[1:]:
            if self.e_options():
                pass
            else:
                print u'Hooops!\n'
                self.help()
                exit(1)
        #elif not argv[1:]:
        #    self.logger.info('You can call the script with' +
        #                     ' some options, use [-h|--help].')#}}}



# VIM MODLINE
# vim: ai ts=4 sw=4 sts=4 expandtab

